from distutils.core import setup
setup(name='input_get',
      version='1.0',
      description='控制台输入显示为星号',
      author='zhaobin',
      author_eamil='zhaobin.lqy@live.cn',
      py_modules=['input_get.py'])
